[−][src]Crate substrate_subxt
A library to submit extrinsics to a substrate node via RPC.
Re-exports
pub use sp_core; |
pub use sp_runtime; |
Modules
| balances | Implements support for the pallet_balances module. |
| contracts | Implements support for the pallet_contracts module. |
| system | Implements support for the frame_system module. |
Macros
| subxt_test |
Structs
| BlockNumber | Wrapper for NumberOrHex to allow custom From impls |
| ChargeTransactionPayment | Require the transactor pay for themselves and maybe include a tip to gain additional priority in the queue. |
| CheckBlockGasLimit | Checks if a transaction would exhausts the block gas limit. |
| CheckEra | Check for transaction mortality. |
| CheckGenesis | Check genesis hash |
| CheckNonce | Nonce check and increment to give replay protection for transactions. |
| CheckVersion | SignedExtra checks copied from substrate, in order to remove requirement to implement
substrate's |
| CheckWeight | Resource limit check. |
| Client | Client to interface with a substrate node. |
| ClientBuilder | ClientBuilder for constructing a Client. |
| DefaultExtra | Default |
| DefaultNodeRuntime | Concrete type definitions compatible with those in the default substrate |
| Encoded | Wraps an already encoded byte vector, prevents being encoded as a raw byte vector as part of the transaction payload |
| EventsDecoder | Event decoder. |
| EventsSubscriber | Submits an extrinsic and subscribes to the triggered events |
| ExtrinsicSuccess | Captures data for when an extrinsic is successfully included in a block |
| KusamaRuntime | Concrete type definitions compatible with those for kusama, v0.7 |
| Metadata | Runtime metadata. |
| RawEvent | Raw bytes for an Event |
| XtBuilder | Transaction builder. |
Enums
| Error | Error enum. |
| EventsError | Events error. |
| MetadataError | Metadata error. |
Traits
| Call | Call trait. |
| Event | Event trait. |
| SignedExtra | Trait for implementing transaction extras for a runtime. |
| Store | Store trait. |
Attribute Macros
| module |
Derive Macros
| Call | |
| Event | |
| Store |